# coding:utf-8
import traceback
import logging

import pxe_fuction

# The attribute that needs to be written

logging.basicConfig(level=logging.INFO)

# First empty the previous configuration
pxe_fuction.command_syn("rm -rf /var/lib/tftpboot/*")

dic = pxe_fuction.read_csv("/etc/auto-pxe/network.csv")
try:
    ip = dic["ip"]
except KeyError:
    logging.info("network.csv does not exist in the file IP, please fill in")

ISO = "/home/clientFusionOS"
fileNames = pxe_fuction.get_file_by_path(ISO)
IsoName = ""
IsoNum = 0
for s in fileNames:
    if s[-3:] == "iso":
        IsoName = s
        IsoNum += 1
Version = 0
# Check the iso and tar imports
if IsoNum == 0:
    logging.info("iso does not exist in the /home/clientFusionOS folder, is the path wrong or forgot to import?")
    logging.info("The script is incorrect")
if IsoNum > 1:
    logging.info("There are multiple isos, the last one will be selected as the default")

# 5.2 To make a judgment, version is version, 0 is x86, and 1 is arm
if IsoName[-11:-4] == "aarch64":
    Version = 1  # 1为arm版本
    logging.info("The client version is arm64")
else:
    logging.info("The client version is x86")

# 6
# 6.2 Upload iso as the yum source
try:
    pxe_fuction.add_yum_from_iso()
except BaseException:
    traceback.logging.info_exc()
    logging.info("Yum source configuration failed, script error")
logging.info("The yum source is configured successfully")

# 7.Turn off the firewall
try:
    pxe_fuction.command_syn("systemctl stop firewalld")
except BaseException:
    traceback.logging.info_exc()
    logging.info("Firewall shutdown failed with incorrect script")
logging.info("The firewall is turned off")

# 8.1.disposition httpd
pxe_fuction.command_syn("dnf install httpd -y")


WELCOME = '/etc/httpd/conf.d/welcome.conf'
pxe_fuction.alter(WELCOME, "Options -Indexes", "")
logging.info("The options were deleted successfully and the httpd configuration was successful")
pxe_fuction.command_syn("systemctl start httpd")
pxe_fuction.command_syn("systemctl enable httpd")
logging.info("The httpd configuration is complete")

# 8.2.Configure tftp
# Install dnf

pxe_fuction.command_syn("dnf install tftp-server -y")
TFTP_NAME = "/etc/xinetd.d/tftp"
pxe_fuction.alter(TFTP_NAME, "disable\t\t\t= yes", "disable\t\t\t= no")
pxe_fuction.command_syn("systemctl start tftp")
pxe_fuction.command_syn("systemctl enable tftp")
logging.info("The tftp configuration is successful")


pxe_fuction.command_syn("umount /mnt")
s = "mount /home/clientFusionOS/%s /mnt/" % IsoName
pxe_fuction.command_syn(s)

pxe_fuction.command_syn("rm -rf /var/www/html/FusionOS/")
pxe_fuction.command_syn("mkdir -m 755 /var/www/html/FusionOS")
files = pxe_fuction.get_file_by_path('/mnt/')
for i in files:
    s = 'cp -r /mnt/%s /var/www/html/FusionOS/' % i
    pxe_fuction.command_syn(s)

logging.info("The tftp configuration is complete")

# 11 , 12 Modify the kickstart configuration file FusionOS-ks.cfg
KICK_START = "/var/www/html/ks/FusionOS-ks.cfg"

pxe_fuction.change_kick_start(KICK_START, ip)
logging.info("FusionOS-ks.cfg file modification successfully")

# 13 Automatically modify the pxe configuration file grub.cfg
if Version == 0:
    pxe_fuction.x86grub(ip, IsoName)
else:
    pxe_fuction.armgrub(ip, IsoName)
logging.info("grub.cfg file modified successfully")

# 14 DHCP configuration

pxe_fuction.add_dhcp(ip, Version)

pxe_fuction.command_syn("umount /mnt")
logging.info("The DHCP configuration is successful and the script is executed")
